Skip to contents

From an object of class 'summary.smfa', coef extracts the coefficients, their standard errors, z-values, and (asymptotic) P-values.

From on object of class 'smfa', it extracts only the estimated coefficients.

Usage

# S3 method for class 'smfa'
coef(object, ...)

# S3 method for class 'summary.smfa'
coef(object, ...)

Arguments

object

A stochastic metafrontier model returned by smfa, or an object of class 'summary.smfa'.

...

Currently ignored.

Value

For objects of class 'summary.smfa', coef returns a matrix with four columns. Namely, the estimated coefficients, their standard errors, z-values, and (asymptotic) P-values.

For objects of class 'smfa', coef returns a numeric vector of the estimated coefficients.

See also

smfa, for the stochastic metafrontier analysis model fitting function using cross-sectional or pooled data.