Skip to contents

fitted returns the fitted frontier values from stochastic metafrontier models estimated with smfa.

Usage

# S3 method for class 'smfa'
fitted(object, ...)

Arguments

object

A stochastic metafrontier model returned by smfa.

...

Currently ignored.

Value

A vector of fitted values is returned.

Note

The fitted values are ordered in the same way as the corresponding observations in the dataset used for the estimation.

See also

smfa, for the stochastic metafrontier analysis model fitting function using cross-sectional or pooled data.