This function returns the residuals' values from stochastic metafrontier models
estimated with smfa.
Arguments
- object
A stochastic metafrontier model returned by
smfa.- ...
Currently ignored.
Note
The residuals values are ordered in the same way as the corresponding observations in the dataset used for the estimation.
See also
smfa, for the stochastic metafrontier analysis model
fitting function using cross-sectional or pooled data.